@@ -40,10 +40,10 @@ extern "C" {
 # include <sys/mount.h>
 #endif
 
-#define LIBMOUNT_VERSION   "2.36.2"
+#define LIBMOUNT_VERSION   "2.36.0"
 #define LIBMOUNT_MAJOR_VERSION   2
 #define LIBMOUNT_MINOR_VERSION   36
-#define LIBMOUNT_PATCH_VERSION   2
+#define LIBMOUNT_PATCH_VERSION   0
 
 /**
  * libmnt_cache:
@@ -941,9 +941,6 @@ extern int mnt_context_set_syscall_status(struct libmnt_context *cxt, int status
 #ifndef MS_DIRSYNC
 #define MS_DIRSYNC	128	/* Directory modifications are synchronous */
 #endif
-#ifndef MS_NOSYMFOLLOW
-#define MS_NOSYMFOLLOW	256	/* Don't follow symlinks */
-#endif
 #ifndef MS_NOATIME
 #define MS_NOATIME	0x400	/* 1024: Do not update access times. */
 #endif
